A simple solution might be the one attached below. Don't know however, if there 
are any side effects. Works for me.

--- x\main.c    2013-12-30 13:27:49.756908800 +0100
+++ main.c      2013-12-30 13:22:35.739224000 +0100
@@ -3892,13 +3892,13 @@
 }
 
 /*
  * Build a ":edit" command to send to a Vim server.
  */
     static char_u *
 build_drop_cmd(filec, filev, tabs, sendReply)
     int                filec;
     char       **filev;
-    int                tabs;           /* Use ":tab edit" instead of ":edit". 
*/
+    int                tabs;           /* Use ":tab drop" instead of ":drop". 
*/
     int                sendReply;
 {
     garray_T   ga;
@@ -3945,7 +3945,7 @@
     ga_concat(&ga, (char_u *)"<CR>:if exists('*inputsave')|call 
inputsave()|endif|");
     if (tabs)
        ga_concat(&ga, (char_u *)"tab ");
-    ga_concat(&ga, (char_u *)"edit");
+    ga_concat(&ga, (char_u *)"drop");
     for (i = 0; i < filec; i++)
     {
        /* On Unix the shell has already expanded the wildcards, don't want to
@@ -3969,13 +3969,13 @@
     }
     ga_concat(&ga, (char_u *)"|if exists('*inputrestore')|call 
inputrestore()|endif<CR>");
 
     /* The :edit commands goes to Insert mode when 'insertmode' is set, use
      * CTRL-\ CTRL-N again. */
     ga_concat(&ga, (char_u *)"<C-\\><C-N>");
 
     /* Switch back to the correct current directory (prior to temporary path
      * switch) unless 'autochdir' is set, in which case it will already be
      * correct after the :edit command. */
     ga_concat(&ga, (char_u *)":if !exists('+acd')||!&acd|cd -|endif<CR>");
 
     if (sendReply)
@@ -3892,13 +3892,13 @@
 
 /*
- * Build a ":edit" command to send to a Vim server.
+ * Build a ":drop" command to send to a Vim server.
  */
     static char_u *
@@ -3969,13 +3969,13 @@
inputrestore()|endif<CR>");
 
-    /* The :edit commands goes to Insert mode when 'insertmode' is set, use
+    /* The :drop commands goes to Insert mode when 'insertmode' is set, use
      * CTRL-\ CTRL-N again. */
     ga_concat(&ga, (char_u *)"<C-\\><C-N>");
@@ -3969,13 +3969,13 @@
     /* Switch back to the correct current directory (prior to temporary path
      * switch) unless 'autochdir' is set, in which case it will already be
-     * correct after the :edit command. */
+     * correct after the :drop command. */
     ga_concat(&ga, (char_u *)":if !exists('+acd')||!&acd|cd -|endif<CR>");
 

-- 
-- 
You received this message from the "vim_dev" maillist.
Do not top-post! Type your reply below the text you are replying to.
For more information, visit http://www.vim.org/maillist.php

--- 
You received this message because you are subscribed to the Google Groups 
"vim_dev" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to vim_dev+unsubscr...@googlegroups.com.
For more options, visit https://groups.google.com/groups/opt_out.

Raspunde prin e-mail lui